@@ -76,7 +76,12 @@ class ProxyCheckResult(models.Model):
         if ip:
             return ip
 
-        g = Grab()
+        g = Grab(
+            hammer_mode=True,
+            hammer_timeouts=defaults.GRABBER_HAMMER_TIMEOUTS,
+            connect_timeout=15,
+            timeout=30
+        )
         g.go("http://ifconfig.me/ip")
         ip = g.response.body.strip()
 
@@ -246,7 +251,7 @@ class Proxy(models.Model):
         (ANONYMITY_HIGH, 'High'),
     )
 
-    hostname = models.CharField(max_length=25, unique=True)
+    hostname = models.CharField(max_length=75, unique=True)
     port = models.PositiveIntegerField()
     user = models.CharField(blank=True, null=True, max_length=50)
     password = models.CharField(blank=True, null=True, max_length=50)
